@@ -1,11 +1,20 @@
 import json
 import time
+import requests
 from data_shipper import config
 from pypact.pact import Pact
 
 pact = Pact()
 
 
+def is_cnx_active():
+    try:
+        requests.head("http://cyberfly.io", timeout=5)
+        return True
+    except requests.ConnectionError:
+        return False
+
+
 def default_meta(sender="not real"):
     return pact.lang.mk_meta(sender, config.chain_id, 0.000001, 80000, time.time().__round__()-15, 28800)
 
